package opmanager

// ManageEngine OpManager
// API Docs
// https://www.manageengine.com/network-monitoring/help/rest-api-opmanager.html#GettingStarted

// Map OpManager states into Naemon states
// Source (severity): https://www.manageengine.com/network-monitoring/help/rest-api-opmanager.html#Devices
// https://www.manageengine.com/network-monitoring/kb/device-availability-state.html

// The Config struct needs to match the json structure from the openITCOCKPIT database
type Config struct {
	Verbose              bool
	ApiUrl               string `json:"api_url"`   // API Endpoint. E.g.: https://opmanager.itsm.love:8061
	ApiKey               string `json:"api_key"`   // API Token
	UseProxy             int    `json:"use_proxy"` // Use a HTTP Proxy (0 or 1)
	ProxyAddress         string // Address of the HTTP Proxy to use (not from DB JSON string)
	IgnoreSslCertificate int    `json:"ignore_ssl_certificate"` // Do not verify the TLS Certificate for HTTPS connections (0 or 1)
	PollingInterval      int64  `json:"polling_interval"`       // Interval in seconds how often the OpManager API should be polled
}

// This value lives in the "statusNum" field (string "1" or int 7 -.-)
const (
	OPMANAGER_STATUS_CRITICAL     int64 = 1 // Red    - A device will be in the 'Critical' state when it does not respond for 5 consecutive availability polls that OpManager triggers. (Device may be down or unavailable)
	OPMANAGER_STATUS_TROUBLE      int64 = 2 // Orange - A device will be in the 'Trouble' state when it does not respond for 3 consecutive availability polls that OpManager triggers. (Device may be down or unavailable)
	OPMANAGER_STATUS_ATTENTION    int64 = 3 // Yellow - A device will be in the 'Attention' state when it does not respond for the 1st availability poll that OpManager triggers. (The particular device may be down or unavailable)
	OPMANAGER_STATUS_SERVICE_DOWN int64 = 4 // Purple - When a service or url monitor associated to the device is down.
	OPMANAGER_STATUS_CLEAR        int64 = 5 // Green  - A device will be in the 'Clear' state when an alarm is cleared and the device is UP and running.
	OPMANAGER_STATUS_UNMANAGED    int64 = 7 // Gray (Not Monitored) - A device will be in the 'Critical' state when it is in the 'Not Monitored' state or the device type is unknown.
)

// This is taken from the WebGUI there is a legend and the numbers are in the HTML source code
// NOTICE - Most of theSTATE NUMBERS ARE UNKNOWN SO FAR !
// This value lives in the "state" field??
const (
	OPMANAGER_AVAILABILITYSTATUS_UP             int64 = 1 // Green  - This corresponds to the device when it is 'UP' and running.
	OPMANAGER_AVAILABILITYSTATUS_DOWN           int64 = 2 // Red    - This corresponds to the device when it is 'Down' or not available.
	OPMANAGER_AVAILABILITYSTATUS_ON_HOLD        int64 = 4 // Light  - Red - This corresponds to the device when it is manually moved to the 'Unmanaged' state.
	OPMANAGER_AVAILABILITYSTATUS_ON_MAINTENANCE int64 = 5 // Gray   -  This corresponds to the device when it is a part of an ongoing downtime schedule (due to which the device will be mpved to the Unmanaged state).

	//OPMANAGER_AVAILABILITYSTATUS_DEPENDENT_UNAVAILABLE int64 = ? // Yellow - This corresponds to the device when the dependent device(s) are down or unavailable.
	//OPMANAGER_AVAILABILITYSTATUS_NOT_MONITORED         int64 = ? // Blue -
)
