package opmanager

import (
	"testing"
)

func TestParseTrafficStrings(t *testing.T) {

	// All this are real world response values from OpManagers /api/json/device/listInterfaces interface
	//strings := []string{
	//	"NA",
	//	"0  (0.0%)",
	//	"23.973  (0.0%)",
	//	"206.489  (0.0%)",
	//	"144.22 K (0.01%)",
	//	"480.147 K (4.8%)",
	//	"2.761 M (2.1%)",
	//	"32.962 M (0.33%)",
	//	"1.923 G (9.62%)",
	//}

	res, err := ParseInterfaceTraffic("NA")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.ParsedSuccessful != false {
		t.Fatal("There is no way we parsed this")
	}

	res, err = ParseInterfaceTraffic("")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.ParsedSuccessful != false {
		t.Fatal("There is no way we parsed this")
	}

	res, err = ParseInterfaceTraffic("0  (0.0%)")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.Traffic != 0 || res.Unit != "B" || res.Percentage != 0 || res.ParsedSuccessful != true {
		t.Fatal("Unexpacted result")
	}

	res, err = ParseInterfaceTraffic("23.973  (0.0%)")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.Traffic != 23.973 || res.Unit != "B" || res.Percentage != 0 || res.ParsedSuccessful != true {
		t.Fatal("Unexpacted result")
	}

	res, err = ParseInterfaceTraffic("144.22 K (0.01%)")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.Traffic != 144.22 || res.Unit != "K" || res.Percentage != 0.01 || res.ParsedSuccessful != true {
		t.Fatal("Unexpacted result")
	}

	res, err = ParseInterfaceTraffic("480.147 K (4.8%)")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.Traffic != 480.147 || res.Unit != "K" || res.Percentage != 4.8 || res.ParsedSuccessful != true {
		t.Fatal("Unexpacted result")
	}

	res, err = ParseInterfaceTraffic("2.761 M (2.1%)")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.Traffic != 2.761 || res.Unit != "M" || res.Percentage != 2.1 || res.ParsedSuccessful != true {
		t.Fatal("Unexpacted result")
	}

	res, err = ParseInterfaceTraffic("32.962 M (0.33%)")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.Traffic != 32.962 || res.Unit != "M" || res.Percentage != 0.33 || res.ParsedSuccessful != true {
		t.Fatal("Unexpacted result")
	}

	res, err = ParseInterfaceTraffic("1.923 G (9.62%)")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.Traffic != 1.923 || res.Unit != "G" || res.Percentage != 9.62 || res.ParsedSuccessful != true {
		t.Fatal("Unexpacted result")
	}

	// I dont know if we can really reach Tbit/s (I just came up with this) better safe than sorry
	res, err = ParseInterfaceTraffic("1.923 T (9.62%)")
	if err != nil {
		t.Fatal("There should be no error")
	}
	if res.Traffic != 1.923 || res.Unit != "T" || res.Percentage != 9.62 || res.ParsedSuccessful != true {
		t.Fatal("Unexpacted result")
	}
}
